'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const VitePluginCssInjectedBundle = () => {
  let styleCode = "";
  return {
    name: "vite-plugin-css-injected-bundle",
    apply: "build",
    enforce: "post",
    generateBundle(_, bundle) {
      for (const key in bundle) {
        const chunk = bundle[key];
        if (chunk.type === "asset" && chunk.fileName.endsWith(".css")) {
          styleCode += chunk.source;
          delete bundle[key];
        }
      }
      for (const key in bundle) {
        const chunk = bundle[key];
        if (chunk.type === "chunk" && chunk.fileName.match(/.[cm]?js$/) !== null && !chunk.fileName.includes("polyfill")) {
          const initialCode = chunk.code;
          chunk.code = `
          (function(){ 
            try {
              var elementStyle = document.createElement('style'); 
              elementStyle.appendChild(document.createTextNode(${JSON.stringify(styleCode.trim())}));
              document.head.appendChild(elementStyle);
            } catch(e) {
              console.error('vite-plugin-css-injected-bundle', e);
            } 
          })();
          `;
          chunk.code += initialCode;
          break;
        }
      }
    }
  };
};

exports.VitePluginCssInjectedBundle = VitePluginCssInjectedBundle;
exports.default = VitePluginCssInjectedBundle;
